==> phrase_api-2.6.1-py3-none-any.whl: phrase_api/api/__init__.py <==
from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from phrase_api.api.accounts_api import AccountsApi
from phrase_api.api.authorizations_api import AuthorizationsApi
from phrase_api.api.bitbucket_sync_api import BitbucketSyncApi
from phrase_api.api.blacklisted_keys_api import BlacklistedKeysApi
from phrase_api.api.branches_api import BranchesApi
from phrase_api.api.comment_reactions_api import CommentReactionsApi
from phrase_api.api.comment_replies_api import CommentRepliesApi
from phrase_api.api.comments_api import CommentsApi
from phrase_api.api.custom_metadata_api import CustomMetadataApi
from phrase_api.api.distributions_api import DistributionsApi
from phrase_api.api.documents_api import DocumentsApi
from phrase_api.api.figma_attachments_api import FigmaAttachmentsApi
from phrase_api.api.formats_api import FormatsApi
from phrase_api.api.git_hub_sync_api import GitHubSyncApi
from phrase_api.api.git_lab_sync_api import GitLabSyncApi
from phrase_api.api.glossaries_api import GlossariesApi
from phrase_api.api.glossary_term_translations_api import GlossaryTermTranslationsApi
from phrase_api.api.glossary_terms_api import GlossaryTermsApi
from phrase_api.api.icu_api import ICUApi
from phrase_api.api.invitations_api import InvitationsApi
from phrase_api.api.job_comments_api import JobCommentsApi
from phrase_api.api.job_locales_api import JobLocalesApi
from phrase_api.api.job_template_locales_api import JobTemplateLocalesApi
from phrase_api.api.job_templates_api import JobTemplatesApi
from phrase_api.api.jobs_api import JobsApi
from phrase_api.api.keys_api import KeysApi
from phrase_api.api.keys_figma_attachments_api import KeysFigmaAttachmentsApi
from phrase_api.api.linked_keys_api import LinkedKeysApi
from phrase_api.api.locale_downloads_api import LocaleDownloadsApi
from phrase_api.api.locales_api import LocalesApi
from phrase_api.api.members_api import MembersApi
from phrase_api.api.notification_groups_api import NotificationGroupsApi
from phrase_api.api.notifications_api import NotificationsApi
from phrase_api.api.orders_api import OrdersApi
from phrase_api.api.organization_job_template_locales_api import OrganizationJobTemplateLocalesApi
from phrase_api.api.organization_job_templates_api import OrganizationJobTemplatesApi
from phrase_api.api.projects_api import ProjectsApi
from phrase_api.api.quality_performance_score_api import QualityPerformanceScoreApi
from phrase_api.api.release_triggers_api import ReleaseTriggersApi
from phrase_api.api.releases_api import ReleasesApi
from phrase_api.api.repo_syncs_api import RepoSyncsApi
from phrase_api.api.reports_api import ReportsApi
from phrase_api.api.screenshot_markers_api import ScreenshotMarkersApi
from phrase_api.api.screenshots_api import ScreenshotsApi
from phrase_api.api.search_api import SearchApi
from phrase_api.api.spaces_api import SpacesApi
from phrase_api.api.style_guides_api import StyleGuidesApi
from phrase_api.api.tags_api import TagsApi
from phrase_api.api.teams_api import TeamsApi
from phrase_api.api.translations_api import TranslationsApi
from phrase_api.api.uploads_api import UploadsApi
from phrase_api.api.users_api import UsersApi
from phrase_api.api.variables_api import VariablesApi
from phrase_api.api.versions_history_api import VersionsHistoryApi
from phrase_api.api.webhook_deliveries_api import WebhookDeliveriesApi
from phrase_api.api.webhooks_api import WebhooksApi

==> phrase_api-3.0.1-py3-none-any.whl: phrase_api/api/__init__.py <==
from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from phrase_api.api.accounts_api import AccountsApi
from phrase_api.api.authorizations_api import AuthorizationsApi
from phrase_api.api.blacklisted_keys_api import BlacklistedKeysApi
from phrase_api.api.branches_api import BranchesApi
from phrase_api.api.comment_reactions_api import CommentReactionsApi
from phrase_api.api.comment_replies_api import CommentRepliesApi
from phrase_api.api.comments_api import CommentsApi
from phrase_api.api.custom_metadata_api import CustomMetadataApi
from phrase_api.api.distributions_api import DistributionsApi
from phrase_api.api.documents_api import DocumentsApi
from phrase_api.api.figma_attachments_api import FigmaAttachmentsApi
from phrase_api.api.formats_api import FormatsApi
from phrase_api.api.glossaries_api import GlossariesApi
from phrase_api.api.glossary_term_translations_api import GlossaryTermTranslationsApi
from phrase_api.api.glossary_terms_api import GlossaryTermsApi
from phrase_api.api.icu_api import ICUApi
from phrase_api.api.invitations_api import InvitationsApi
from phrase_api.api.job_comments_api import JobCommentsApi
from phrase_api.api.job_locales_api import JobLocalesApi
from phrase_api.api.job_template_locales_api import JobTemplateLocalesApi
from phrase_api.api.job_templates_api import JobTemplatesApi
from phrase_api.api.jobs_api import JobsApi
from phrase_api.api.keys_api import KeysApi
from phrase_api.api.keys_figma_attachments_api import KeysFigmaAttachmentsApi
from phrase_api.api.linked_keys_api import LinkedKeysApi
from phrase_api.api.locale_downloads_api import LocaleDownloadsApi
from phrase_api.api.locales_api import LocalesApi
from phrase_api.api.members_api import MembersApi
from phrase_api.api.notification_groups_api import NotificationGroupsApi
from phrase_api.api.notifications_api import NotificationsApi
from phrase_api.api.orders_api import OrdersApi
from phrase_api.api.organization_job_template_locales_api import OrganizationJobTemplateLocalesApi
from phrase_api.api.organization_job_templates_api import OrganizationJobTemplatesApi
from phrase_api.api.projects_api import ProjectsApi
from phrase_api.api.quality_performance_score_api import QualityPerformanceScoreApi
from phrase_api.api.release_triggers_api import ReleaseTriggersApi
from phrase_api.api.releases_api import ReleasesApi
from phrase_api.api.repo_sync_events_api import RepoSyncEventsApi
from phrase_api.api.repo_syncs_api import RepoSyncsApi
from phrase_api.api.reports_api import ReportsApi
from phrase_api.api.screenshot_markers_api import ScreenshotMarkersApi
from phrase_api.api.screenshots_api import ScreenshotsApi
from phrase_api.api.search_api import SearchApi
from phrase_api.api.spaces_api import SpacesApi
from phrase_api.api.style_guides_api import StyleGuidesApi
from phrase_api.api.tags_api import TagsApi
from phrase_api.api.teams_api import TeamsApi
from phrase_api.api.translations_api import TranslationsApi
from phrase_api.api.uploads_api import UploadsApi
from phrase_api.api.users_api import UsersApi
from phrase_api.api.variables_api import VariablesApi
from phrase_api.api.versions_history_api import VersionsHistoryApi
from phrase_api.api.webhook_deliveries_api import WebhookDeliveriesApi
from phrase_api.api.webhooks_api import WebhooksApi
